/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.uima.test;

import org.apache.uima.analysis_engine.ResultSpecification;
import org.apache.uima.analysis_engine.annotator.AnnotatorConfigurationException;
import org.apache.uima.analysis_engine.annotator.AnnotatorContext;
import org.apache.uima.analysis_engine.annotator.AnnotatorContextException;
import org.apache.uima.analysis_engine.annotator.AnnotatorInitializationException;
import org.apache.uima.analysis_engine.annotator.AnnotatorProcessException;
import org.apache.uima.analysis_engine.annotator.TextAnnotator;
import org.apache.uima.cas.CAS;
import org.apache.uima.cas.CASException;
import org.apache.uima.cas.TypeSystem;
import org.apache.uima.jcas.tcas.DocumentAnnotation;
import org.apache.uima.util.Level;
import org.apache.uima.util.Logger;

import uima.test.MyType;

public class AnalysisEngine2 implements TextAnnotator {

  private Logger logger;

  public AnalysisEngine2() {
    // do nothing
  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.analysis_engine.annotator.TextAnnotator#process(org.apache.uima.cas.CAS,
   *      org.apache.uima.analysis_engine.ResultSpecification)
   */
  public void process(CAS cas, ResultSpecification aResultSpec) throws AnnotatorProcessException {
    this.logger.log(Level.INFO, "process AnalysisEngine annotator");

    try {
      MyType type = new MyType(cas.getJCas());
      type.setBegin(0);
      type.setEnd(2);
      type.setTestFeature("Test");
      type.addToIndexes();
      
      DocumentAnnotation documentAnnot = (DocumentAnnotation) cas.getJCas().getDocumentAnnotationFs();
      documentAnnot.getBegin();
      documentAnnot.getEnd();
      documentAnnot.setTestFeature2("test value 2");

    } catch (CASException ex) {

      throw new AnnotatorProcessException(ex);
    }

  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.analysis_engine.annotator.BaseAnnotator#destroy()
   */
  public void destroy() {
    // do nothing
  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.analysis_engine.annotator.BaseAnnotator#initialize(org.apache.uima.analysis_engine.annotator.AnnotatorContext)
   */
  public void initialize(AnnotatorContext aContext) throws AnnotatorInitializationException,
          AnnotatorConfigurationException {

    try {

      // initialize logger
      this.logger = aContext.getLogger();

      // check datapath setting for the test annotator
      String datapath = aContext.getDataPath();
      if (!datapath.equals("/home/uima/test/datapath")) {
        throw new AnnotatorContextException(new RuntimeException(
                "UIMA datapath setting is not correct!"));
      }

      // check system properties for the test annotator
      String propertyValue = System.getProperty("analysisEnginePearTestKey");
      if (!propertyValue.equals("analysisEnginePearTestKeyValue")) {
        throw new AnnotatorContextException(new RuntimeException(
                "analysis engine annotator system property is not correct!"));
      }

    } catch (AnnotatorContextException ex) {
      throw new AnnotatorInitializationException(ex);
    }

    this.logger.log(Level.INFO, "initialize AnalysisEngine annotator");

  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.analysis_engine.annotator.BaseAnnotator#reconfigure()
   */
  public void reconfigure() throws AnnotatorConfigurationException,
          AnnotatorInitializationException {
    // do nothing
  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.analysis_engine.annotator.BaseAnnotator#typeSystemInit(org.apache.uima.cas.TypeSystem)
   */
  public void typeSystemInit(TypeSystem aTypeSystem) throws AnnotatorInitializationException,
          AnnotatorConfigurationException {
    // do nothing
  }

}
